Class: StarkInfra::IssuingCard::Log

Inherits:
Utils::Resource show all
Defined in:
lib/issuingcard/log.rb

Overview

# IssuingCard::Log object

Every time an IssuingCard entity is updated, a corresponding issuing card.Log is generated for the entity. This log is never generated by the user, but it can be retrieved to check additional information on the IssuingCard.

## Attributes:

  • id [string]: unique id returned when the log is created. ex: ‘5656565656565656’

  • created [DateTime]: creation datetime for the log. ex: DateTime.new(2020, 3, 10, 10, 30, 0, 0)

  • type [string]: type of the IssuingCard event which triggered the log creation. ex: ‘processing’ or ‘success’

  • card [IssuingCard]: IssuingCard entity to which the log refers to.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Utils::SubResource

#inspect, #to_s

Constructor Details

#initialize(id:, created:, type:, card:) ⇒ Log

Returns a new instance of Log.



22
23
24
25
26
27
# File 'lib/issuingcard/log.rb', line 22

def initialize(id:, created:, type:, card:)
  super(id)
  @type = type
  @card = card
  @created = StarkInfra::Utils::Checks.check_datetime(created)
end

Instance Attribute Details

#cardObject (readonly)

Returns the value of attribute card.



21
22
23
# File 'lib/issuingcard/log.rb', line 21

def card
  @card
end

#createdObject (readonly)

Returns the value of attribute created.



21
22
23
# File 'lib/issuingcard/log.rb', line 21

def created
  @created
end

#idObject (readonly)

Returns the value of attribute id.



21
22
23
# File 'lib/issuingcard/log.rb', line 21

def id
  @id
end

#typeObject (readonly)

Returns the value of attribute type.



21
22
23
# File 'lib/issuingcard/log.rb', line 21

def type
  @type
end

Class Method Details

.get(id, user: nil) ⇒ Object

# Retrieve a specific Log

Receive a single Log object previously created by the Stark Infra API by passing its id

## Parameters (required):

  • id [string]: object unique id. ex: ‘5656565656565656’

## Parameters (optional):

  • user [Organization/Project object, default nil]: Organization or Project object. Not necessary if StarkInfra.user was set before function call

## Return:

  • Log object with updated attributes



41
42
43
# File 'lib/issuingcard/log.rb', line 41

def self.get(id, user: nil)
  StarkInfra::Utils::Rest.get_id(id: id, user: user, **resource)
end

.page(cursor: nil, limit: nil, after: nil, before: nil, types: nil, card_ids: nil, user: nil) ⇒ Object

# Retrieve paged Logs

Receive a list of up to 100 Log objects previously created in the Stark Infra API and the cursor to the next page. Use this function instead of query if you want to manually page your logs.

## Parameters (optional):

  • cursor [string, default nil]: cursor returned on the previous page function call

  • ids [list of strings, default nil]: list of ids to filter retrieved objects. ex: [‘5656565656565656’, ‘4545454545454545’]

  • limit [integer, default 100]: maximum number of objects to be retrieved. Max = 100. ex: 35

  • after [Date or string, default nil] date filter for objects created only after specified date. ex: Date.new(2020, 3, 10)

  • before [Date or string, default nil] date filter for objects created only before specified date. ex: Date.new(2020, 3, 10)

  • types [list of strings, default nil]: filter for log event types. ex: [‘blocked’, ‘canceled’, ‘created’, ‘expired’, ‘unblocked’, ‘updated’]

  • card_ids [list of strings, default nil]: list of IssuingCard ids to filter logs. ex: [‘5656565656565656’, ‘4545454545454545’]

  • user [Organization/Project object, default nil]: Organization or Project object. Not necessary if starkinfra.user was set before function call

## Return:

  • list of Log objects with updated attributes

  • Cursor to retrieve the next page of Log objects



92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/issuingcard/log.rb', line 92

def self.page(cursor: nil, limit: nil, after: nil, before: nil, types: nil, card_ids: nil, user: nil)
  after = StarkInfra::Utils::Checks.check_date(after)
  before = StarkInfra::Utils::Checks.check_date(before)
  StarkInfra::Utils::Rest.get_page(
    cursor: cursor,
    limit: limit,
    after: after,
    before: before,
    types: types,
    card_ids: card_ids,
    user: user,
    **resource
  )
end

.query(limit: nil, after: nil, before: nil, types: nil, card_ids: nil, user: nil) ⇒ Object

# Retrieve Logs

Receive a generator of Log objects previously created in the Stark Infra API

## Parameters (optional):

  • ids [list of strings, default nil]: list of ids to filter retrieved objects. ex: [‘5656565656565656’, ‘4545454545454545’]

  • limit [integer, default nil]: maximum number of objects to be retrieved. Unlimited if nil. ex: 35

  • after [Date or string, default nil] date filter for objects created only after specified date. ex: Date.new(2020, 3, 10)

  • before [Date or string, default nil] date filter for objects created only before specified date. ex: Date.new(2020, 3, 10)

  • types [list of strings, default nil]: filter for log event types. ex: [‘blocked’, ‘canceled’, ‘created’, ‘expired’, ‘unblocked’, ‘updated’]

  • card_ids [list of strings, default nil]: list of IssuingCard ids to filter logs. ex: [‘5656565656565656’, ‘4545454545454545’]

  • user [Organization/Project object, default nil]: Organization or Project object. Not necessary if starkinfra.user was set before function call

## Return:

  • generator of Log objects with updated attributes



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/issuingcard/log.rb', line 60

def self.query(limit: nil, after: nil, before: nil, types: nil, card_ids: nil, user: nil)
  after = StarkInfra::Utils::Checks.check_date(after)
  before = StarkInfra::Utils::Checks.check_date(before)
  StarkInfra::Utils::Rest.get_stream(
    limit: limit,
    after: after,
    before: before,
    types: types,
    card_ids: card_ids,
    user: user,
    **resource
  )
end

.resourceObject



107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/issuingcard/log.rb', line 107

def self.resource
  request_maker = StarkInfra::IssuingCard.resource[:resource_maker]
  {
    resource_name: 'IssuingCardLog',
    resource_maker: proc { |json|
      Log.new(
        id: json['id'],
        created: json['created'],
        type: json['type'],
        card: StarkInfra::Utils::API.from_api_json(request_maker, json['card'])
      )
    }
  }
end